@@ -248,6 +248,14 @@ enum
 #define CS_SEC_APPDEFINED CS_SEC_APPDEFINED
 	CS_STICKY_BINDS = 9151,
 #define CS_STICKY_BINDS CS_STICKY_BINDS
+	CS_SEC_NETWORKAUTH = 9175,
+#define CS_SEC_NETWORKAUTH CS_SEC_NETWORKAUTH
+	CS_SEC_DELEGATION = 9176,
+#define CS_SEC_DELEGATION CS_SEC_DELEGATION
+	CS_SEC_MUTUALAUTH = 9177,
+#define CS_SEC_MUTUALAUTH CS_SEC_MUTUALAUTH
+	CS_SEC_SERVERPRINCIPAL = 9188,
+#define CS_SEC_SERVERPRINCIPAL CS_SEC_SERVERPRINCIPAL
 	CS_SERVERADDR = 9206,
 #define CS_SERVERADDR CS_SERVERADDR
 	CS_PORT = 9300,
@@ -449,11 +457,22 @@ enum
 #define CS_SEND_DATA_CMD 151
 #define CS_SEND_BULK_CMD 153
 
+#ifdef CS_NO_LARGE_IDENTIFIERS
 #define CS_VERSION_100	112
 #define CS_VERSION_110	1100
 #define CS_VERSION_120	1100
 #define CS_VERSION_125	12500
 #define CS_VERSION_150	15000
+#else
+#define CS_VERSION_100	113
+#define CS_VERSION_110	1101
+#define CS_VERSION_120	CS_VERSION_110
+#define CS_VERSION_125	12501
+#define CS_VERSION_150	15001
+#define CS_VERSION_155	15501
+#define CS_VERSION_157	15701
+#define CS_VERSION_160	16001
+#endif
 
 #define BLK_VERSION_100 CS_VERSION_100
 #define BLK_VERSION_110 CS_VERSION_110
@@ -592,6 +611,9 @@ enum
 #define CS_BIGTIME_TYPE     TDS_STATIC_CAST(CS_INT, 36)
 #define CS_UNIQUE_TYPE      TDS_STATIC_CAST(CS_INT, 40)
 
+#define CS_MIN_SYBTYPE CS_CHAR_TYPE
+#define CS_MAX_SYBTYPE CS_UNIQUE_TYPE
+
 #define CS_USER_TYPE        TDS_STATIC_CAST(CS_INT, 100)
 /* cs_dt_info type values */
 enum
@@ -674,9 +696,15 @@ typedef struct _cs_objname
 {
 	CS_BOOL thinkexists;
 	CS_INT object_type;
+#ifdef CS_NO_LARGE_IDENTIFIERS
 	CS_CHAR last_name[CS_MAX_NAME];
 	CS_INT lnlen;
 	CS_CHAR first_name[CS_MAX_NAME];
+#else
+	CS_CHAR last_name[CS_MAX_CHAR];
+	CS_INT lnlen;
+	CS_CHAR first_name[CS_MAX_CHAR];
+#endif
 	CS_INT fnlen;
 	CS_VOID *scope;
 	CS_INT scopelen;
